@@ -3,9 +3,12 @@
 Note that this module only works on trains from the Deutsche Bahn
 Note that this module only works while connected to the on board network "WIFI@DB" or "WIFIonICE"
 """
-import requests
+from requests import get
 from datetime import datetime, timedelta
-from math import pi, sin, cos, sqrt, atan, radians
+################################################
+
+version = '1.0.7'
+################################################
 
 class NetworkException(Exception):
     """Exception raised when a request fails to fetch data from the api
@@ -62,7 +65,7 @@ class WrongApiException(Exception):
             return f'This function requires data from the "{self.api} API"'
         else:
             return self.message
-
+################################################
 
 def convert_time_to_string(timedelta_obj, locale="en", no_seconds=False):
     """Converts a timedelta object into a readable string.
@@ -126,6 +129,7 @@ def cut_timestamp(seconds):
 def calc_distance(position_start, position_end):
     """Calculates the distance beween two positions in format (lat, lon)
     """
+    from math import pi, sin, cos, sqrt, atan, radians
     f = 1/298.257223563
     a = 6378173
     F = radians((position_start[0] + position_end[0])/2.0)
@@ -142,11 +146,26 @@ def calc_distance(position_start, position_end):
     H_2 = (3*T+1)/(2*S)
     return D * (1 + f * H_1 * sin(F)**2 * cos(G)**2 - f * H_2 * cos(F)**2 * sin(G)**2)
 
+def autoupdate():
+    """Update the module if outdated
+    """
+    from subprocess import check_output
+    from sys import executable
+    from os import system
+    for row in check_output([executable, "-m", "pip", "list", "--outdated"]).decode('utf-8').split('wheel\r\n')[2:-1]:
+        module_info = []
+        for p in row.split(' '):
+            if not ' ' == p and not '' == p:
+                module_info.append(p)
+        if 'iceportal-apis' == info[0]:
+            system(f'{executable} -m pip install --upgrade iceportal-apis')
+################################################
+
 def request_json(url):
     """Requests data from 'url' and parses it as a dictionary
     """
     try:
-        data = requests.get(url)
+        data = get(url)
     except:
         raise NetworkException(url)
     try:
@@ -169,6 +188,7 @@ def get_all():
     """Pulls data from the api and returns it as dictionaries.
     """
     return get_status(), get_trip()
+################################################
 
 def get_speed(status_call=None):
     """Gets the current speed of the train in kilometers/hour.
@@ -215,11 +235,15 @@ def get_position(status_call=None):
     return (get_latitude(), get_longitude())
 
 def get_train_id(status_call=None):
+    """Gets the ID of the train
+    """
     if status_call != None:
         return status_call['tzn']
     return get_status()['tzn']
 
 def get_trip_id(trip_call=None):
+    """Gets the ID of the trip
+    """
     if trip_call != None:
         return trip_call['trip']['vzn']
     return get_trip()['trip']['vzn']
@@ -568,13 +592,30 @@ def get_station_position(station_name=None, evaNr=None, trip_call=None):
         if stop['station'][key] == value:
             return (stop['station']['geocoordinates']['latitude'], stop['station']['geocoordinates']['longitude'])
 
-def get_station_distance(station_name=None, evaNr=None, status_call=None, trip_call=None):
+def get_station_distance(station_name=None, evaNr=None, trip_call=None):
     """Calculates the distance to a specific station and returns it in meters
     """
+    if station_name != None:
+        key = 'name'
+        value = station_name
+    elif evaNr != None:
+        key = 'evaNr'
+        value = evaNr
+    else:
+        raise TypeError('Missing at least one argument: station_name, evaNr')
+    if trip_call == None:
+        trip_call = get_trip()
+    for stop in trip_call['trip']['stops']:
+        if stop['station'][key] == value:
+            return stop['info']['distanceFromStart'] - trip['data']['actualPosition']
+
+def get_station_distance_complex(station_name=None, evaNr=None, status_call=None, trip_call=None):
+    """Calculates the distance to a specific station and returns it in meters
+    """
+    if station_name == None and evaNr == None:
+        raise TypeError('Missing at least one argument: station_name, evaNr')
     if trip_call == None:
         trip_call = get_trip()
     if status_call == None:
         status_call = get_status()
-    else:
-        raise TypeError('Missing at least one argument: station_name, evaNr')
     return calc_distance(get_position(status_call=status_call), get_station_position(station_name=station_name, evaNr=evaNr, trip_call=trip_call))
